/***********************************************************************
*
* Copyright (c) 2021-2024 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();
};

MainWindow::MainWindow()
{
   QString osName    = "Unknown";
   QString osEdition = "Unspecified";

#if defined(Q_OS_WIN)
   QSysInfo::WinVersion winVersion = QSysInfo::windowsVersion();

   osName    = "Windows";
   osEdition = QSysInfo::windowsEdition(winVersion);

#elif defined(Q_OS_DARWIN)
   QSysInfo::MacVersion macVersion = QSysInfo::macVersion();

   osName    = "Mac OS X";
   osEdition = QSysInfo::macEdition(macVersion);

#else
   osName = "Unix";

#endif

   setMinimumSize(400, 200);

   QLabel *label_1 = new QLabel();
   label_1->setText("Operating System:   " + osName);

   QLabel *label_2 = new QLabel();
   label_2->setText("OS Edition:   " + osEdition);

   QPushButton *pb = new QPushButton();
   pb->setText("Close");

   QFrame *box = new QFrame();
   box->setLineWidth(1);
   box->setFrameStyle(QFrame::Box);

   QVBoxLayout *layout1 = new QVBoxLayout(box);
   layout1->setContentsMargins(20, 20, 20, 20);
   layout1->addWidget(label_1);
   layout1->addSpacing(20);
   layout1->addWidget(label_2);
   layout1->addStretch();

   QHBoxLayout *layout2 = new QHBoxLayout();
   layout2->addStretch();
   layout2->addWidget(pb);
   layout2->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->setContentsMargins(80, 55, 80, 15);
   layoutMain->addWidget(box);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout2);

   connect(pb, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
